package eu.jonahbauer.wizard.client.libgdx.screens;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.g2d.TextureRegion;
import com.badlogic.gdx.scenes.scene2d.Actor;
import com.badlogic.gdx.scenes.scene2d.ui.TextButton;
import com.badlogic.gdx.scenes.scene2d.utils.ChangeListener;
import eu.jonahbauer.wizard.client.libgdx.MenuAtlas;
import eu.jonahbauer.wizard.client.libgdx.WizardGame;
import eu.jonahbauer.wizard.client.libgdx.listeners.KeyboardFocusManager;
import eu.jonahbauer.wizard.client.libgdx.state.Menu;

public class MainMenuScreen extends MenuScreen {

    private TextButton buttonPlay;
    private TextButton buttonQuit;

    private TextureRegion[] symbols;

    private final ChangeListener listener = new ChangeListener() {
        @Override
        public void changed(ChangeEvent event, Actor actor) {
            if (actor == buttonPlay) {
                game.getClient().execute(Menu.class, Menu::showConnectScreen);
                sfxClick();
            } else if (actor == buttonQuit) {
                sfxClick();
                Gdx.app.exit();
            }
        }
    };

    public MainMenuScreen(WizardGame game) {
        super(game);
    }

    @Override
    public void show() {
        super.show();

        symbols = new TextureRegion[] {
                atlas.findRegion(MenuAtlas.SYMBOL_0),
                atlas.findRegion(MenuAtlas.SYMBOL_1),
                atlas.findRegion(MenuAtlas.SYMBOL_2),
                atlas.findRegion(MenuAtlas.SYMBOL_3)
        };

        buttonPlay = new TextButton(messages.get("menu.main.play"), skin);
        buttonPlay.setPosition((WizardGame.WIDTH - buttonPlay.getWidth()) / 2f, 192 + 504 - 120f - 125f);
        buttonPlay.addListener(listener);

        buttonQuit = new TextButton(messages.get("menu.main.quit"), skin);
        buttonQuit.setPosition((WizardGame.WIDTH - buttonQuit.getWidth()) / 2f, 192 + 120f);
        buttonQuit.addListener(listener);

        stage.addActor(buttonPlay);
        stage.addActor(buttonQuit);
        stage.addCaptureListener(new KeyboardFocusManager(buttonPlay, buttonQuit));

        buttonPlay.setName("button_player");
        buttonQuit.setName("button_quit");
    }

    @Override
    protected void renderForeground(float delta) {
        super.renderForeground(delta);
        int width = 160, height = 224;
        int left = 384, right = 384, top = 384, bottom = 192;
        batch.draw(symbols[0], left, bottom, width, height);
        batch.draw(symbols[1], left, WizardGame.HEIGHT - top - height, width, height);
        batch.draw(symbols[2], WizardGame.WIDTH - right - width, bottom, width, height);
        batch.draw(symbols[3], WizardGame.WIDTH - right - width, WizardGame.HEIGHT - top - height, width, height);
    }
}
